@@ -2,13 +2,12 @@ package Mojolicious::Plugin::RoutesAuthDBI;
 use Mojo::Base 'Mojolicious::Plugin::Authentication';
 use Mojo::Loader qw(load_class);
 
-our $VERSION = '0.413';
+our $VERSION = '0.414';
 
 my $access;# 
 my $pkg = __PACKAGE__;
 my $conf ;# set on ->registrer
 
-
 my $fail_auth = {format=>'txt', text=>"Deny at auth step. Please sign in!!!\n"};
 my $fail_auth_cb = sub {shift->render(%$fail_auth);};
 my $fail_access_cb = sub {
@@ -23,8 +22,6 @@ my $fail_access_cb = sub {
   
 };
 
-
-
 sub register {
   my ($self, $app,) = (shift, shift);
   $conf = shift; # global
@@ -216,7 +213,7 @@ sub access {# add_condition
 
 =head1 VERSION
 
-0.413
+0.414
 
 =head1 NAME
 
@@ -305,21 +302,41 @@ See L<Mojolicious::Plugin::RoutesAuthDBI::Install>.
 
 Heart of this plugin! This condition apply for all db routes even if column auth set to 0. It is possible to apply this condition to non db routes:
 
-  $r->route('/foo')->...->over(access=>{auth=>0})->...;# no access check to route, but authorization by session will ready
-  
-  $r->route('/bar-bar-any-namespace')->to('bar#bar',)->over(access=>{auth=>1})->...;# route accessible if user roles assigned to either B<loadable> namespace or controller 'Bar.pm' (which assigned neither namespece on db or assigned to that loadable namespace) or action 'bar' on controller Bar.pm (action record in table actions)
-  
-  $r->route('/bar-bar-bar')->to('bar#bar', namespace=>'Bar')->over(access=>{auth=>1})->...;# because explicit defined namespace route accessible either namespace 'Bar' or 'Bar::Bar.pm' controller or action 'bar' in controller 'Bar.pm' which assigned to namespace 'Bar'.
-  
-  $r->route('/bar-nsX')->to('bar#bar', namespace=>'Bar')->over(access=>{auth=>1, namespace=>'BarX'})->...;# check access by overriden namespace 'BarX': controller and action also with that namespace in db refs
-  
-  $r->route('/bar-nsX-cX')->to('bar#bar', namespace=>'Bar')->over(access=>{auth=>1, namespace=>'BarX', controller=>'BarX'})->...;# check access by overriden namespace 'BarX' and controller 'BarX.pm', action record also with that ns & c in db refs
-  
-  $r->route('/bar-nsX-cX-aX')->to('bar#bar', namespace=>'Bar')->over(access=>{auth=>1, namespace=>'BarX', controller=>'BarX', action=>'barX'})->...;# full override names access
-  
-  $r->route('/bar-cX-aX')->to('bar#bar',)->over(access=>{auth=>1, controller=>'BarX', action=>'barX'})->...;#
-  
-  $r->route('/bar-role-admin')->to('bar#bar',)->over(access=>{auth=>1, role=> 'admin'})->...;# accessible if user roles list has defined role (admin)
+=over 4
+
+=item * No access check to route, but authorization by session will ready:
+
+  $r->route('/foo')->...->over(access=>{auth=>0})->...;
+
+=item * Route accessible if user roles assigned to either B<loadable> namespace or controller 'Bar.pm' (which assigned neither namespece on db or assigned to that loadable namespace) or action 'bar' on controller Bar.pm (action record in db table actions):
+
+  $r->route('/bar-bar-any-namespace')->to('bar#bar',)->over(access=>{auth=>1})->...;
+
+=item * Explicit defined namespace route accessible either namespace 'Bar' or 'Bar::Bar.pm' controller or action 'bar' in controller 'Bar::Bar.pm' (which assigned to namespace 'Bar' in table refs):
+
+  $r->route('/bar-bar-bar')->to('bar#bar', namespace=>'Bar')->over(access=>{auth=>1})->...;
+
+=item * Check access by overriden namespace 'BarX': controller and action also with that namespace in db table refs:
+
+  $r->route('/bar-nsX')->to('bar#bar', namespace=>'Bar')->over(access=>{auth=>1, namespace=>'BarX'})->...;
+
+=item * Check access by overriden namespace 'BarX' and controller 'BarX.pm', action record also with that ns & c in db table refs:
+
+  $r->route('/bar-nsX-cX')->to('bar#bar', namespace=>'Bar')->over(access=>{auth=>1, namespace=>'BarX', controller=>'BarX'})->...;
+
+=item * Full override names access:
+
+  $r->route('/bar-nsX-cX-aX')->to('bar#bar', namespace=>'Bar')->over(access=>{auth=>1, namespace=>'BarX', controller=>'BarX', action=>'barX'})->...;
+
+=item *
+
+  $r->route('/bar-cX-aX')->to('bar#bar',)->over(access=>{auth=>1, controller=>'BarX', action=>'barX'})->...;
+
+=item * Route accessible if user roles list has defined role (admin):
+
+  $r->route('/bar-role-admin')->to('bar#bar',)->over(access=>{auth=>1, role=> 'admin'})->...;
+
+=back
 
 =head1 HELPERS
 
